@@ -110,6 +110,7 @@ def wrap_app(cls: type[App], **kwargs) -> IsolatedFunction:
     metadata["openapi"] = app.openapi()
 
     routes = app.collect_routes()
+    initialize_and_serve._routes = [r.path for r in routes.keys()] or ["/"]  # type: ignore[attr-defined]
     realtime_app = any(route.is_websocket for route in routes)
 
     kind = cls.host_kwargs.pop("kind", "virtualenv")
@@ -337,8 +338,10 @@ class App(BaseServable):
 
     def __init__(self, *, _allow_init: bool = False):
         if not _allow_init and not os.getenv("IS_ISOLATE_AGENT"):
+            cls_name = self.__class__.__name__
             raise NotImplementedError(
-                "Running apps through SDK is not implemented yet."
+                "Running apps through SDK is not implemented yet. "
+                f"Please use `fal run path/to/app.py::{cls_name}` to run your app."
             )
 
     @classmethod
