@@ -1,12 +1,16 @@
 from __future__ import annotations
 
 import tempfile
+import unittest.mock
 from pathlib import Path
 from typing import Callable
 from uuid import uuid4
 
-import fal
 import pytest
+from pydantic import BaseModel, Field
+from pydantic import __version__ as pydantic_version
+
+import fal
 from fal import FalServerlessHost, FalServerlessKeyCredentials, local, sync_dir
 from fal.api import FalServerlessError, IsolatedFunction
 from fal.toolkit import (
@@ -19,9 +23,9 @@ from fal.toolkit import (
     Image as FalImage,
 )
 from fal.toolkit.file.file import CompressedFile
-from fal.toolkit.utils.download_utils import _get_git_revision_hash, _hash_url
-from pydantic import BaseModel, Field
-from pydantic import __version__ as pydantic_version
+from fal.toolkit.utils.download_utils import _git_rev_parse, _hash_url
+
+EXAMPLE_FILE_URL = "https://raw.githubusercontent.com/fal-ai/fal/main/projects/fal/tests/assets/cat.png"
 
 
 @pytest.mark.flaky(max_runs=3)
@@ -197,11 +201,9 @@ def mock_fal_persistent_dirs(monkeypatch):
 def test_download_file(isolated_client, mock_fal_persistent_dirs):
     from fal.toolkit.utils.download_utils import FAL_PERSISTENT_DIR
 
-    EXAMPLE_FILE_URL = "https://raw.githubusercontent.com/fal-ai/isolate/d553f927348206530208442556f481f39b161732/README.md"
-
     relative_directory = "test"
     output_directory = FAL_PERSISTENT_DIR / relative_directory
-    expected_path = output_directory / "README.md"
+    expected_path = output_directory / "cat.png"
 
     @isolated_client()
     def absolute_path_persistent_dir():
@@ -301,8 +303,7 @@ def test_download_model_weights(isolated_client, mock_fal_persistent_dirs):
 
     print(FAL_MODEL_WEIGHTS_DIR)
 
-    EXAMPLE_FILE_URL = "https://raw.githubusercontent.com/fal-ai/isolate/d553f927348206530208442556f481f39b161732/README.md"
-    expected_path = FAL_MODEL_WEIGHTS_DIR / _hash_url(EXAMPLE_FILE_URL) / "README.md"
+    expected_path = FAL_MODEL_WEIGHTS_DIR / _hash_url(EXAMPLE_FILE_URL) / "cat.png"
 
     @isolated_client()
     def download_weights():
@@ -354,6 +355,12 @@ def test_clone_repository(isolated_client, mock_fal_persistent_dirs):
     EXAMPLE_REPO_FIRST_COMMIT = "64b0a89c8391bd2cb3ca23cdeae01779e11aee05"
     EXAMPLE_REPO_SECOND_COMMIT = "34ecbca8cc7b64719d2a5c40dd3272f8d13bc1d2"
     expected_path = FAL_REPOSITORY_DIR / "isolate"
+    first_expected_path = (
+        FAL_REPOSITORY_DIR / f"isolate-{EXAMPLE_REPO_FIRST_COMMIT[:8]}"
+    )
+    second_expected_path = (
+        FAL_REPOSITORY_DIR / f"isolate-{EXAMPLE_REPO_SECOND_COMMIT[:8]}"
+    )
 
     @isolated_client()
     def clone_without_commit_hash():
@@ -369,13 +376,13 @@ def test_clone_repository(isolated_client, mock_fal_persistent_dirs):
         first_path = clone_repository(
             EXAMPLE_REPO_URL, commit_hash=EXAMPLE_REPO_FIRST_COMMIT
         )
-        first_repo_hash = _get_git_revision_hash(first_path)
+        first_repo_hash = _git_rev_parse(first_path, "HEAD")
 
         second_path = clone_repository(
             EXAMPLE_REPO_URL, commit_hash=EXAMPLE_REPO_SECOND_COMMIT
         )
 
-        second_repo_hash = _get_git_revision_hash(repo_path)
+        second_repo_hash = _git_rev_parse(second_path, "HEAD")
 
         return first_path, first_repo_hash, second_path, second_repo_hash
 
@@ -386,8 +393,12 @@ def test_clone_repository(isolated_client, mock_fal_persistent_dirs):
         second_repo_hash,
     ) = clone_with_commit_hash()
 
-    assert str(expected_path) == str(first_path), "Path should be the target location"
-    assert str(expected_path) == str(second_path), "Path should be the target location"
+    assert str(first_expected_path) == str(
+        first_path
+    ), "Path should be the target location"
+    assert str(second_expected_path) == str(
+        second_path
+    ), "Path should be the target location"
 
     assert (
         first_repo_hash == EXAMPLE_REPO_FIRST_COMMIT
@@ -431,9 +442,15 @@ def test_clone_repository(isolated_client, mock_fal_persistent_dirs):
         third_repo_stat,
     ) = clone_with_force()
 
-    assert str(expected_path) == str(first_path), "Path should be the target location"
-    assert str(expected_path) == str(second_path), "Path should be the target location"
-    assert str(expected_path) == str(third_path), "Path should be the target location"
+    assert str(first_expected_path) == str(
+        first_path
+    ), "Path should be the target location"
+    assert str(first_expected_path) == str(
+        second_path
+    ), "Path should be the target location"
+    assert str(first_expected_path) == str(
+        third_path
+    ), "Path should be the target location"
 
     assert (
         first_repo_stat.st_mtime == second_repo_stat.st_mtime
@@ -457,7 +474,7 @@ def fal_file_content_matches(file: File, content: str):
 
 
 def test_fal_file_from_path(isolated_client):
-    @isolated_client(requirements=[f"pydantic=={pydantic_version}"])
+    @isolated_client(requirements=[f"pydantic=={pydantic_version}", "tomli"])
     def fal_file_from_temp(content: str):
         with tempfile.NamedTemporaryFile() as temp_file:
             file_path = temp_file.name
@@ -474,7 +491,7 @@ def test_fal_file_from_path(isolated_client):
 
 
 def test_fal_file_from_bytes(isolated_client):
-    @isolated_client(requirements=[f"pydantic=={pydantic_version}"])
+    @isolated_client(requirements=[f"pydantic=={pydantic_version}", "tomli"])
     def fal_file_from_bytes(content: str):
         return File.from_bytes(content.encode(), repository="in_memory")
 
@@ -485,7 +502,7 @@ def test_fal_file_from_bytes(isolated_client):
 
 
 def test_fal_file_save(isolated_client):
-    @isolated_client(requirements=[f"pydantic=={pydantic_version}"])
+    @isolated_client(requirements=[f"pydantic=={pydantic_version}", "tomli"])
     def fal_file_to_local_file(content: str):
         file = File.from_bytes(content.encode(), repository="in_memory")
 
@@ -510,8 +527,8 @@ def test_fal_file_save(isolated_client):
     "file_url, expected_content",
     [
         (
-            "https://raw.githubusercontent.com/fal-ai/fal/fe0e2a1aa4b46a42a93bad0fbd9aca4aefcb4296/README.md",
-            "projects/fal/README.md",
+            EXAMPLE_FILE_URL,
+            "projects/fal/cat.png",
         ),
         ("data:text/plain;charset=UTF-8,fal", "fal"),
     ],
@@ -520,7 +537,7 @@ def test_fal_file_input(isolated_client, file_url: str, expected_content: str):
     class TestInput(BaseModel):
         file: File = Field()
 
-    @isolated_client(requirements=[f"pydantic=={pydantic_version}"])
+    @isolated_client(requirements=[f"pydantic=={pydantic_version}", "tomli"])
     def init_file_on_fal(input: TestInput) -> File:
         return input.file
 
@@ -541,7 +558,7 @@ def test_fal_compressed_file(isolated_client):
     class TestInput(BaseModel):
         files: CompressedFile
 
-    @isolated_client(requirements=[f"pydantic=={pydantic_version}"])
+    @isolated_client(requirements=[f"pydantic=={pydantic_version}", "tomli"])
     def init_compressed_file_on_fal(input: TestInput) -> int:
         extracted_file_paths = [file for file in input.files]
         return extracted_file_paths
@@ -556,11 +573,28 @@ def test_fal_compressed_file(isolated_client):
 
 
 def test_fal_cdn(isolated_client):
-
-    @isolated_client(requirements=[f"pydantic=={pydantic_version}"])
+    @isolated_client(requirements=[f"pydantic=={pydantic_version}", "tomli"])
     def upload_to_fal_cdn() -> FalImage:
         return FalImage.from_bytes(b"0", "jpeg", repository="cdn")
 
     uploaded_image = upload_to_fal_cdn()
 
     assert uploaded_image
+
+
+def test_download_file_with_slash_in_filename():
+    from fal.toolkit.utils.download_utils import _get_remote_file_properties
+
+    test_url = "https://example.com/file/with/slash.txt"
+
+    with unittest.mock.patch(
+        "fal.toolkit.utils.download_utils.urlopen"
+    ) as mock_urlopen:
+        # urlopen is a context manager, so we need to mock the __enter__ method
+        mock_response = mock_urlopen.return_value.__enter__.return_value
+        mock_response.headers.get_filename.return_value = "file/with/slash.txt"
+        mock_response.headers.get.return_value = "100"
+
+        file_name, _ = _get_remote_file_properties(test_url)
+
+    assert "/" not in file_name
